@@ -1,6 +1,6 @@
-import mon  # noqa
-from install import install, mirror_install, repo_install  # noqa
-from uninstall import uninstall  # noqa
+from . import mon  # noqa
+from .install import install, mirror_install, repo_install  # noqa
+from .uninstall import uninstall  # noqa
 from ceph_deploy.util import pkg_managers
 
 # Allow to set some information about this distro
