@@ -85,6 +85,8 @@ def install(args):
     if args.repo:
         return install_repo(args)
 
+    gpgcheck = 0 if args.nogpgcheck else 1
+
     if args.version_kind == 'stable':
         version = args.release
     else:
@@ -147,6 +149,8 @@ def install(args):
             gpg_url = gpg_fallback
 
         if args.local_mirror:
+            if args.username:
+                hostname = "%s@%s" % (args.username, hostname)
             remoto.rsync(hostname, args.local_mirror, '/opt/ceph-deploy/repo', distro.conn.logger, sudo=True)
             repo_url = 'file:///opt/ceph-deploy/repo'
             gpg_url = 'file:///opt/ceph-deploy/repo/release.asc'
@@ -169,6 +173,7 @@ def install(args):
                 gpg_url,
                 args.adjust_repos,
                 components=components,
+                gpgcheck=gpgcheck,
             )
 
         # Detect and install custom repos here if needed
@@ -183,6 +188,7 @@ def install(args):
                 version,
                 args.adjust_repos,
                 components=components,
+                gpgcheck = gpgcheck,
             )
 
         # Check the ceph version we just installed
@@ -582,6 +588,12 @@ def make(parser):
                 (defaults to ceph.com)'
     )
 
+    parser.add_argument(
+        '--nogpgcheck',
+        action='store_true',
+        help='install packages without gpgcheck',
+    )
+
     parser.set_defaults(
         func=install,
     )
